@@ -27,8 +27,8 @@ package
 package Data::Dumper::Interp;
 
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 997.999; }
-our $VERSION = '7.007'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2024-04-26'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '7.008'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2024-12-01'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Moose;
 
@@ -46,7 +46,6 @@ use List::Util 1.45 qw(min max first none all any sum0);
 use Data::Structure::Util qw/circular_off/;
 use Regexp::Common qw/RE_balanced/;
 use Term::ReadKey ();
-use Capture::Tiny qw/capture_merged/;
 use overload ();
 
 ############################ Exports #######################################
@@ -418,10 +417,9 @@ sub __win_forceqsh(_) {
   # parameter to a command typed to cmd.com in Windows.
   # However parameter parameter parsing is implemented within each command
   # and there is no universal ruleset.   For example Strawberry perl
-  # appears to split parameters on white space only whereas (as I understand
-  # it) Windows commands, at least built-in ones, split words on any of
+  # appears to split parameters on white space only, whereas (as I understand)
+  # Windows commands, at least built-in ones, split words on any of
   # space tab , ; or = and all those must be protected, see
-  #
   #    https://ss64.com/nt/syntax-esc.html
   #
   # For the moment at least, qsh "quotes" words so they come through when
@@ -647,11 +645,12 @@ sub _get_terminal_width() {  # returns undef if unknowable
       # "stty" directly prints "stdin is not a tty" which we can not trap.
       # Probably this is a bug in Term::Readkey where it should redirect
       # such messages to /dev/null.  So we have to do it here.
-      () = capture_merged {
+      require Capture::Tiny;
+      () = Capture::Tiny::capture_merged(sub{
         delete local $INC{__WARN__};
         delete local $INC{__DIE__};
         ($width, $height) = eval{ Term::ReadKey::GetTerminalSize($fh) };
-      }
+      });
     }
     return $width; # possibly undef (sometimes seems to be zero ?!?)
   }
